<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="39"/>
        <source>Row</source>
        <translation>Række</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="40"/>
        <source>Column</source>
        <translation>Kolonne</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="41"/>
        <source>Characters %1</source>
        <translation>Tegn %1</translation>
    </message>
</context>
<context>
    <name>DDropdownMenu</name>
    <message>
        <location filename="../src/widgets/ddropdownmenu.cpp" line="300"/>
        <location filename="../src/widgets/ddropdownmenu.cpp" line="344"/>
        <location filename="../src/widgets/ddropdownmenu.cpp" line="349"/>
        <source>None</source>
        <translation type="unfinished">Ingen</translation>
    </message>
</context>
<context>
    <name>EditWrapper</name>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="647"/>
        <source>File has changed on disk. Reload?</source>
        <translation>Filen er blevet ændret på disken. Genindlæs?</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="642"/>
        <source>File removed on the disk. Save it now?</source>
        <translation>Filen er fjernet fra disken. Gem den nu?</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="316"/>
        <source>Do you want to save this file?</source>
        <translation type="unfinished">Vil du gemme filen?</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="320"/>
        <source>Discard</source>
        <translation type="unfinished">Forkast</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="259"/>
        <source>Encoding changed. Do you want to save the file now?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="445"/>
        <source>You do not have permission to save %1</source>
        <translation type="unfinished">Du har ikke tilladelse til at gemme %1</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="669"/>
        <location filename="../src/widgets/bottombar.cpp" line="60"/>
        <source>INSERT</source>
        <translation>INDSÆT</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="672"/>
        <source>OVERWRITE</source>
        <translation>OVERSKRIV</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="675"/>
        <source>R/O</source>
        <translation>SB</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="262"/>
        <location filename="../src/editor/editwrapper.cpp" line="319"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="201"/>
        <location filename="../src/editor/editwrapper.cpp" line="264"/>
        <location filename="../src/editor/editwrapper.cpp" line="321"/>
        <location filename="../src/editor/editwrapper.cpp" line="571"/>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
</context>
<context>
    <name>FindBar</name>
    <message>
        <location filename="../src/controls/findbar.cpp" line="40"/>
        <source>Find</source>
        <translation>Find</translation>
    </message>
    <message>
        <location filename="../src/controls/findbar.cpp" line="46"/>
        <source>Next</source>
        <translation>Næste</translation>
    </message>
    <message>
        <location filename="../src/controls/findbar.cpp" line="44"/>
        <source>Previous</source>
        <translation>Forrige</translation>
    </message>
</context>
<context>
    <name>JumpLineBar</name>
    <message>
        <location filename="../src/controls/jumplinebar.cpp" line="40"/>
        <source>Go to Line: </source>
        <translation>Gå til linje: </translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/editorapplication.cpp" line="27"/>
        <source>Text Editor is a powerful tool for viewing and editing text files.</source>
        <translation>Teksteditor er et kraftfuldt værktøj til at vise og redigere tekstfiler.</translation>
    </message>
    <message>
        <location filename="../src/editorapplication.cpp" line="38"/>
        <source>Text Editor</source>
        <translation>Teksteditor</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/startmanager.cpp" line="765"/>
        <source>File not saved</source>
        <translation>Filen er ikke gemt</translation>
    </message>
    <message>
        <location filename="../src/editorapplication.cpp" line="35"/>
        <source>Text Editor</source>
        <translation>Teksteditor</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="24"/>
        <source>Basic</source>
        <translation>Grundlæggende</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="25"/>
        <source>Font Style</source>
        <translation>Skriftstil</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="26"/>
        <source>Font</source>
        <translation>Skrifttype</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="27"/>
        <source>Font Size</source>
        <translation>Skriftstørrelse</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="29"/>
        <location filename="../src/controls/settingsdialog.cpp" line="30"/>
        <source>Keymap</source>
        <translation>Tegnkort</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="28"/>
        <source>Shortcuts</source>
        <translation>Genveje</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="58"/>
        <source>Forward character</source>
        <translation>Et tegn fremad</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="59"/>
        <source>Backward character</source>
        <translation>Et tegn tilbage</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="92"/>
        <source>Transpose character</source>
        <translation>Omvendte tegn</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="109"/>
        <source>Tab width</source>
        <translation>Tabulatorbredde</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="111"/>
        <source>Word wrap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="31"/>
        <location filename="../src/controls/settingsdialog.cpp" line="107"/>
        <location filename="../src/widgets/window.cpp" line="1490"/>
        <source>Window</source>
        <translation>Vindue</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="32"/>
        <source>New tab</source>
        <translation>Nyt faneblad</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="33"/>
        <source>New window</source>
        <translation>Nyt vindue</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="34"/>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="35"/>
        <source>Save as</source>
        <translation>Gem som</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="36"/>
        <source>Next tab</source>
        <translation>Næste faneblad</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="37"/>
        <source>Previous tab</source>
        <translation>Forrige faneblad</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="38"/>
        <source>Close tab</source>
        <translation>Luk faneblad</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="39"/>
        <source>Close other tabs</source>
        <translation>Luk andre faneblade</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="40"/>
        <source>Restore tab</source>
        <translation>Gendan faneblad</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="41"/>
        <source>Open file</source>
        <translation>Åbn fil</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="42"/>
        <source>Increment font size</source>
        <translation>Større skriftstørrelse</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="43"/>
        <source>Decrement font size</source>
        <translation>Mindre skriftstørrelse</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="44"/>
        <source>Reset font size</source>
        <translation>Nulstil skriftstørrelse</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="46"/>
        <source>Toggle fullscreen</source>
        <translation>Fuldskærm til/fra</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="45"/>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="47"/>
        <source>Find</source>
        <translation>Find</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="48"/>
        <source>Replace</source>
        <translation>Erstat</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="49"/>
        <source>Go to line</source>
        <translation>Gå til linje</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="50"/>
        <source>Save cursor position</source>
        <translation>Gem markørplacering</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="51"/>
        <source>Reset cursor position</source>
        <translation>Nulstil markørplacering</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="52"/>
        <source>Exit</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="53"/>
        <source>Display shortcuts</source>
        <translation>Vis genveje</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="54"/>
        <source>Print</source>
        <translation>Udskriv</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="55"/>
        <source>Editor</source>
        <translation>Editor</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="56"/>
        <source>Increase indent</source>
        <translation>Større indrykning</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="57"/>
        <source>Decrease indent</source>
        <translation>Mindre indrykning</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="60"/>
        <source>Forward word</source>
        <translation>Et ord fremad</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="61"/>
        <source>Backward word</source>
        <translation>Et ord tilbage</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="62"/>
        <source>Next line</source>
        <translation>Næste linje</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="63"/>
        <source>Previous line</source>
        <translation>Forrige linje</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="64"/>
        <source>New line</source>
        <translation>Ny linje</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="65"/>
        <source>New line above</source>
        <translation>Ny linje nedenfor</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="66"/>
        <source>New line below</source>
        <translation>Ny linje ovenfor</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="67"/>
        <source>Duplicate line</source>
        <translation>Dupliker linje</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="68"/>
        <source>Delete to end of line</source>
        <translation>Slet til slutningen af linjen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="69"/>
        <source>Delete current line</source>
        <translation>Slet nuværende linje</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="70"/>
        <source>Swap line up</source>
        <translation>Ombyt linje op</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="71"/>
        <source>Swap line down</source>
        <translation>Ombyt linje ned</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="72"/>
        <source>Scroll up one line</source>
        <translation>Rul en linje op</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="73"/>
        <source>Scroll down one line</source>
        <translation>Rul en linje ned</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="74"/>
        <source>Page up</source>
        <translation>Side op</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="75"/>
        <source>Page down</source>
        <translation>Side ned</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="76"/>
        <source>Move to end of line</source>
        <translation>Flyt til slutningen af linjen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="77"/>
        <source>Move to start of line</source>
        <translation>Flyt til begyndelsen af linjen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="78"/>
        <source>Move to end of text</source>
        <translation>Flyt til slutningen af teksten</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="79"/>
        <source>Move to start of text</source>
        <translation>Flyt til begyndelsen af teksten</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="80"/>
        <source>Move to line indentation</source>
        <translation>Flyt til linjeindrykning</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="81"/>
        <source>Upper case</source>
        <translation>Store bogstaver</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="82"/>
        <source>Lower case</source>
        <translation>Små bogstaver</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="83"/>
        <source>Capitalize</source>
        <translation>Stort begyndelsesbogstav</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="84"/>
        <source>Delete backward word</source>
        <translation>Slet et ord tilbage</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="85"/>
        <source>Delete forward word</source>
        <translation>Slet et ord fremad</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="86"/>
        <source>Forward over a pair</source>
        <translation>Fremad over et par</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="87"/>
        <source>Backward over a pair</source>
        <translation>Tilbage over et par</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="88"/>
        <source>Select all</source>
        <translation>Markér alt</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="89"/>
        <source>Copy</source>
        <translation>Kopiér</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="90"/>
        <source>Cut</source>
        <translation>Klip</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="91"/>
        <source>Paste</source>
        <translation>Indsæt</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="93"/>
        <source>Mark</source>
        <translation>Sæt mærke</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="94"/>
        <source>Unmark</source>
        <translation>Fjern mærke</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="95"/>
        <source>Copy line</source>
        <translation>Kopiér linje</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="96"/>
        <source>Cut line</source>
        <translation>Klip linje</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="97"/>
        <source>Merge lines</source>
        <translation>Sammenlæg linjer</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="98"/>
        <source>Read-Only mode</source>
        <translation>Skrivebeskyttet tilstand</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="99"/>
        <source>Add comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="100"/>
        <source>Remove comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="101"/>
        <source>Undo</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="102"/>
        <source>Redo</source>
        <translation>Omgør</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="103"/>
        <source>Add/Remove bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="104"/>
        <source>Move to previous bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="105"/>
        <source>Move to next bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="106"/>
        <source>Advanced</source>
        <translation>Avanceret</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="108"/>
        <source>Window size</source>
        <translation>Vinduesstørrelse</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="112"/>
        <source>Code folding flag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="113"/>
        <source>Show line numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="114"/>
        <source>Show bookmarks icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="115"/>
        <source>Show whitespaces and tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="116"/>
        <source>Highlight current line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="120"/>
        <source>Unicode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="121"/>
        <source>WesternEuropean</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="122"/>
        <source>CentralEuropean</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="123"/>
        <source>Baltic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="124"/>
        <source>Cyrillic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="125"/>
        <source>Arabic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="130"/>
        <source>Celtic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="131"/>
        <source>SouthEasternEuropean</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="126"/>
        <source>Greek</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="127"/>
        <source>Hebrew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="132"/>
        <source>ChineseSimplified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="133"/>
        <source>ChineseTraditional</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="134"/>
        <source>Japanese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="135"/>
        <source>Korean</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="129"/>
        <source>Thai</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="128"/>
        <source>Turkish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="136"/>
        <source>Vietnamese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="117"/>
        <source>Color mark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="203"/>
        <location filename="../src/editor/editwrapper.cpp" line="573"/>
        <location filename="../src/widgets/window.cpp" line="964"/>
        <location filename="../src/widgets/window.cpp" line="981"/>
        <location filename="../src/widgets/window.cpp" line="1072"/>
        <location filename="../src/widgets/window.cpp" line="1087"/>
        <source>Encoding</source>
        <translation type="unfinished">Kodning</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="982"/>
        <location filename="../src/widgets/window.cpp" line="1073"/>
        <location filename="../src/widgets/window.cpp" line="1088"/>
        <source>Line Endings</source>
        <translation type="unfinished">Linjeskift</translation>
    </message>
</context>
<context>
    <name>ReplaceBar</name>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="39"/>
        <source>Find</source>
        <translation>Find</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="43"/>
        <source>Replace With</source>
        <translation>Erstat med</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="47"/>
        <source>Replace</source>
        <translation>Erstat</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="50"/>
        <source>Skip</source>
        <translation>Spring over</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="53"/>
        <source>Replace Rest</source>
        <translation>Erstat resten</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="56"/>
        <source>Replace All</source>
        <translation>Erstat alle</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../src/common/settings.cpp" line="132"/>
        <source>Standard</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="132"/>
        <source>Customize</source>
        <translation>Tilpas</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="145"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="145"/>
        <source>Maximum</source>
        <translation>Maksimum</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="145"/>
        <source>Fullscreen</source>
        <translation>Fuldskærm</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="333"/>
        <source>This shortcut conflicts with system shortcut %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="335"/>
        <source>This shortcut conflicts with %1, click on Replace to make this shortcut effective immediately</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="481"/>
        <location filename="../src/common/settings.cpp" line="489"/>
        <source>The shortcut %1 is invalid, please set another one.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="524"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="525"/>
        <source>Replace</source>
        <translation>Erstat</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="527"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StartManager</name>
    <message>
        <location filename="../src/startmanager.cpp" line="340"/>
        <source>Untitled %1</source>
        <translation type="unfinished">Unavngivet %1</translation>
    </message>
</context>
<context>
    <name>Tabbar</name>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="515"/>
        <source>Close tab</source>
        <translation>Luk faneblad</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="517"/>
        <source>More options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="518"/>
        <source>Close tabs to the left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="519"/>
        <source>Close tabs to the right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="520"/>
        <source>Close unmodified tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="516"/>
        <source>Close other tabs</source>
        <translation>Luk andre faneblade</translation>
    </message>
</context>
<context>
    <name>TextEdit</name>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="235"/>
        <source>Undo</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="236"/>
        <source>Redo</source>
        <translation>Omgør</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="237"/>
        <source>Cut</source>
        <translation>Klip</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="238"/>
        <source>Copy</source>
        <translation>Kopiér</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="239"/>
        <source>Paste</source>
        <translation>Indsæt</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="240"/>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="241"/>
        <source>Select All</source>
        <translation>Markér alt</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="242"/>
        <location filename="../src/widgets/window.cpp" line="361"/>
        <source>Find</source>
        <translation>Find</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="243"/>
        <location filename="../src/widgets/window.cpp" line="362"/>
        <source>Replace</source>
        <translation>Erstat</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="244"/>
        <source>Go to Line</source>
        <translation>Gå til linje</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="245"/>
        <source>Turn on Read-Only mode</source>
        <translation>Aktivér skrivebeskyttet tilstand</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="246"/>
        <source>Turn off Read-Only mode</source>
        <translation>Deaktivér skrivebeskyttet tilstand</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="247"/>
        <source>Fullscreen</source>
        <translation>Fuldskærm</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="248"/>
        <source>Exit fullscreen</source>
        <translation>Afslut fuldskærm</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="249"/>
        <source>Display in file manager</source>
        <translation>Vis i filhåndtering</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="250"/>
        <location filename="../src/editor/dtextedit.cpp" line="302"/>
        <source>Add Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="255"/>
        <source>Column Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="303"/>
        <source>Remove Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="2537"/>
        <source>Copy failed: not enough memory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="2621"/>
        <source>Press ALT and click lines to edit in column mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="251"/>
        <source>Text to Speech</source>
        <translation>Tekst til tale</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="252"/>
        <source>Stop reading</source>
        <translation>Stop læsning</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="253"/>
        <source>Speech to Text</source>
        <translation>Tale til tekst</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="254"/>
        <source>Translate</source>
        <translation>Oversæt</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="256"/>
        <source>Add bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="257"/>
        <source>Remove Bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="258"/>
        <source>Previous bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="259"/>
        <source>Next bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="260"/>
        <source>Remove All Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="261"/>
        <source>Fold All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="262"/>
        <source>Fold Current Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="263"/>
        <source>Unfold All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="264"/>
        <source>Unfold Current Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="269"/>
        <source>Color Mark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="295"/>
        <source>Mark All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="283"/>
        <source>Mark</source>
        <translation>Sæt mærke</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="273"/>
        <source>Clear All Marks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="274"/>
        <source>Clear Last Mark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="346"/>
        <source>Change Case</source>
        <translation>Skift store/små bogstaver</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="347"/>
        <source>Upper Case</source>
        <translation>Store bogstaver</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="348"/>
        <source>Lower Case</source>
        <translation>Små bogstaver</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="349"/>
        <source>Capitalize</source>
        <translation>Stort begyndelsesbogstav</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="64"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1183"/>
        <source>Selected line(s) copied</source>
        <translation>Valgte linje(r) kopieret</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1189"/>
        <source>Current line copied</source>
        <translation>Nuværende linje kopieret</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1209"/>
        <source>Selected line(s) clipped</source>
        <translation>Valgte linje(r) beskåret</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1220"/>
        <source>Current line clipped</source>
        <translation>Nuværende linje beskåret</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="2547"/>
        <source>Paste failed: not enough memory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="3444"/>
        <source>Read-Only mode is off</source>
        <translation>Skrivebeskyttet tilstand er deaktiveret</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="3451"/>
        <location filename="../src/editor/dtextedit.cpp" line="3470"/>
        <location filename="../src/editor/dtextedit.cpp" line="6185"/>
        <source>Read-Only mode is on</source>
        <translation>Skrivebeskyttet tilstand er aktiveret</translation>
    </message>
</context>
<context>
    <name>WarningNotices</name>
    <message>
        <location filename="../src/controls/warningnotices.cpp" line="36"/>
        <source>Reload</source>
        <translation>Genindlæs</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/widgets/window.cpp" line="353"/>
        <source>New window</source>
        <translation>Nyt vindue</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="354"/>
        <source>New tab</source>
        <translation>Nyt faneblad</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="355"/>
        <source>Open file</source>
        <translation>Åbn fil</translation>
    </message>
    <message>
        <location filename="../src/controls/warningnotices.cpp" line="38"/>
        <location filename="../src/widgets/window.cpp" line="357"/>
        <source>Save as</source>
        <translation>Gem som</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="358"/>
        <source>Print</source>
        <translation>Udskriv</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="359"/>
        <source>Switch theme</source>
        <translation>Skift tema</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="471"/>
        <location filename="../src/widgets/window.cpp" line="2489"/>
        <source>Read-Only</source>
        <translation>Skrivebeskyttet</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="926"/>
        <source>Saved successfully</source>
        <translation>Gemt</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1219"/>
        <source>Read-Only mode is on</source>
        <translation>Skrivebeskyttet tilstand er aktiveret</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1500"/>
        <source>Ctrl+&apos;=&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1503"/>
        <source>Ctrl+&apos;-&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="2237"/>
        <source>Discard</source>
        <translation>Forkast</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="360"/>
        <location filename="../src/widgets/window.cpp" line="1550"/>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="487"/>
        <source>You do not have permission to open %1</source>
        <translation>Du har ikke tilladelse til at åbne %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="522"/>
        <source>Invalid file: %1</source>
        <translation>Ugyldig fil: %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="962"/>
        <location filename="../src/widgets/window.cpp" line="1029"/>
        <location filename="../src/widgets/window.cpp" line="1070"/>
        <source>Save File</source>
        <translation>Gem fil</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="602"/>
        <location filename="../src/widgets/window.cpp" line="644"/>
        <source>Do you want to save this file?</source>
        <translation>Vil du gemme filen?</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1031"/>
        <source>Encoding</source>
        <translation>Kodning</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1532"/>
        <source>Editor</source>
        <translation>Editor</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="902"/>
        <source>You do not have permission to save %1</source>
        <translation>Du har ikke tilladelse til at gemme %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1911"/>
        <source>Untitled %1</source>
        <translation>Unavngivet %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1449"/>
        <source>Current location remembered</source>
        <translation>Nuværende placering husket</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="2236"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="356"/>
        <location filename="../src/widgets/window.cpp" line="2238"/>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
</context>
</TS>
